Signed-off-by: Aline Manera <alinefm(a)linux.vnet.ibm.com>
---
src/wok/plugins/gingerbase/model/host.py | 4 +-
src/wok/plugins/gingerbase/swupdate.py | 6 +-
src/wok/plugins/gingerbase/tests/utils.py | 2 +-
.../plugins/gingerbase/ui/js/src/gingerbase.api.js | 14 +--
.../gingerbase/ui/js/src/gingerbase.host.js | 126 ++++++++++-----------
.../gingerbase/ui/js/src/gingerbase.main.js | 10 +-
.../ui/js/src/gingerbase.report_add_main.js | 10 +-
.../ui/js/src/gingerbase.report_rename_main.js | 10 +-
.../ui/js/src/gingerbase.repository_add_main.js | 6 +-
.../ui/js/src/gingerbase.repository_edit_main.js | 12 +-
src/wok/plugins/gingerbase/ui/pages/host.html.tmpl | 4 +-
.../gingerbase/ui/pages/report-add.html.tmpl | 2 +-
.../gingerbase/ui/pages/report-rename.html.tmpl | 2 +-
.../gingerbase/ui/pages/repository-add.html.tmpl | 2 +-
.../gingerbase/ui/pages/repository-edit.html.tmpl | 2 +-
15 files changed, 106 insertions(+), 106 deletions(-)
diff --git a/src/wok/plugins/gingerbase/swupdate.py
b/src/wok/plugins/gingerbase/swupdate.py
index 6ac98e2..bc8d721 100644
--- a/src/wok/plugins/gingerbase/swupdate.py
+++ b/src/wok/plugins/gingerbase/swupdate.py
@@ -128,9 +128,9 @@ class SoftwareUpdate(object):
def tailUpdateLogs(self, cb, params):
"""
- When the package manager is already running (started outside kimchi or
- if wokd is restarted) we can only know what's happening by reading the
- logfiles. This method acts like a 'tail -f' on the default package
+ When the package manager is already running (started outside gingerbase
+ or if wokd is restarted) we can only know what's happening by reading
+ the logfiles. This method acts like a 'tail -f' on the default package
manager logfile. If the logfile is not found, a simple '*' is
displayed to track progress. This will be until the process finishes.
"""
diff --git a/src/wok/plugins/gingerbase/tests/utils.py
b/src/wok/plugins/gingerbase/tests/utils.py
index 13054dd..b800ac4 100644
--- a/src/wok/plugins/gingerbase/tests/utils.py
+++ b/src/wok/plugins/gingerbase/tests/utils.py
@@ -165,7 +165,7 @@ def request(host, port, path, data=None, method='GET',
headers=None):
def get_remote_iso_path():
"""
Get a remote iso with the right arch from the distro files shipped
- with kimchi.
+ with gingerbase.
"""
host_arch = os.uname()[4]
remote_path = ''
diff --git a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.api.js
b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.api.js
index db6543f..5f7fa0e 100644
--- a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.api.js
+++ b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.api.js
@@ -17,7 +17,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-var kimchi = {
+var gingerbase = {
widget: {},
@@ -144,7 +144,7 @@ var kimchi = {
case 'running':
progress && progress(result);
setTimeout(function() {
- kimchi.trackTask(taskID, suc, err, progress);
+ gingerbase.trackTask(taskID, suc, err, progress);
}, 2000);
break;
case 'finished':
@@ -158,15 +158,15 @@ var kimchi = {
}
};
- kimchi.getTask(taskID, onTaskResponse, err);
- if(kimchi.trackingTasks.indexOf(taskID) < 0)
- kimchi.trackingTasks.push(taskID);
+ gingerbase.getTask(taskID, onTaskResponse, err);
+ if(gingerbase.trackingTasks.indexOf(taskID) < 0)
+ gingerbase.trackingTasks.push(taskID);
},
createReport: function(settings, suc, err, progress) {
var onResponse = function(data) {
taskID = data['id'];
- kimchi.trackTask(taskID, suc, err, progress);
+ gingerbase.trackTask(taskID, suc, err, progress);
};
wok.requestJSON({
@@ -241,7 +241,7 @@ var kimchi = {
};
var trackTask = function() {
- kimchi.getTask(taskID, onTaskResponse, err);
+ gingerbase.getTask(taskID, onTaskResponse, err);
};
var onTaskResponse = function(result) {
diff --git a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.main.js
b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.main.js
index 326f943..0f5fe75 100644
--- a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.main.js
+++ b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.main.js
@@ -17,12 +17,12 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-kimchi.capabilities = undefined;
-kimchi.getCapabilities(function(result) {
- kimchi.capabilities = result;
+gingerbase.capabilities = undefined;
+gingerbase.getCapabilities(function(result) {
+ gingerbase.capabilities = result;
- if(kimchi.capabilities.federation=="on")
+ if(gingerbase.capabilities.federation=="on")
$('#peers').removeClass('hide-content');
}, function() {
- kimchi.capabilities = {};
+ gingerbase.capabilities = {};
});
diff --git a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.report_rename_main.js
b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.report_rename_main.js
index b5538f1..8cca36a 100644
--- a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.report_rename_main.js
+++ b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.report_rename_main.js
@@ -17,7 +17,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-kimchi.report_rename_main = function() {
+gingerbase.report_rename_main = function() {
var renameReportForm = $('#form-report-rename');
var submitButton = $('#button-report-rename');
var nameTextbox = $('input[name="name"]', renameReportForm);
@@ -29,7 +29,7 @@ kimchi.report_rename_main = function() {
// if the user hasn't changed the report's name,
// nothing should be done.
- if (reportName == kimchi.selectedReport) {
+ if (reportName == gingerbase.selectedReport) {
wok.message.error.code('GGBDR6013M');
return false;
}
@@ -42,11 +42,11 @@ kimchi.report_rename_main = function() {
var formData = renameReportForm.serializeObject();
submitButton.prop('disabled', true);
nameTextbox.prop('disabled', true);
- kimchi.renameReport(kimchi.selectedReport, formData, function(result) {
+ gingerbase.renameReport(gingerbase.selectedReport, formData, function(result) {
submitButton.prop('disabled', false);
nameTextbox.prop('disabled', false);
wok.window.close();
- wok.topic('kimchi/debugReportRenamed').publish({
+ wok.topic('gingerbase/debugReportRenamed').publish({
result: result
});
}, function(result) {
@@ -64,5 +64,5 @@ kimchi.report_rename_main = function() {
renameReportForm.on('submit', submitForm);
submitButton.on('click', submitForm);
- nameTextbox.val(kimchi.selectedReport).select();
+ nameTextbox.val(gingerbase.selectedReport).select();
};
diff --git a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.repository_add_main.js
b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.repository_add_main.js
index 59fe7a5..f359f77 100644
--- a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.repository_add_main.js
+++ b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.repository_add_main.js
@@ -17,7 +17,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-kimchi.repository_add_main = function() {
+gingerbase.repository_add_main = function() {
var addForm = $('#form-repository-add');
var addButton = $('#button-repository-add');
@@ -82,8 +82,8 @@ kimchi.repository_add_main = function() {
}
}
- kimchi.createRepository(formData, function() {
- wok.topic('kimchi/repositoryAdded').publish();
+ gingerbase.createRepository(formData, function() {
+ wok.topic('gingerbase/repositoryAdded').publish();
wok.window.close();
}, function(jqXHR, textStatus, errorThrown) {
var reason = jqXHR &&
diff --git a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.repository_edit_main.js
b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.repository_edit_main.js
index 24677cc..ff45ab7 100644
--- a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.repository_edit_main.js
+++ b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.repository_edit_main.js
@@ -17,20 +17,20 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-kimchi.repository_edit_main = function() {
+gingerbase.repository_edit_main = function() {
var editForm = $('#form-repository-edit');
var saveButton = $('#repository-edit-button-save');
- if(kimchi.capabilities['repo_mngt_tool']=="yum") {
+ if(gingerbase.capabilities['repo_mngt_tool']=="yum") {
editForm.find('input.deb').prop('disabled', true);
}
- else if(kimchi.capabilities['repo_mngt_tool']=="deb") {
+ else if(gingerbase.capabilities['repo_mngt_tool']=="deb") {
editForm.find('input.yum').prop('disabled', true);
}
- kimchi.retrieveRepository(kimchi.selectedRepository, function(repository) {
+ gingerbase.retrieveRepository(gingerbase.selectedRepository, function(repository) {
editForm.fillWithObject(repository);
$('input', editForm).on('input propertychange', function(event)
{
@@ -58,8 +58,8 @@ kimchi.repository_edit_main = function() {
}
}
- kimchi.updateRepository(kimchi.selectedRepository, formData, function() {
- wok.topic('kimchi/repositoryUpdated').publish();
+ gingerbase.updateRepository(gingerbase.selectedRepository, formData, function()
{
+ wok.topic('gingerbase/repositoryUpdated').publish();
wok.window.close();
}, function(jqXHR, textStatus, errorThrown) {
var reason = jqXHR &&
diff --git a/src/wok/plugins/gingerbase/ui/pages/host.html.tmpl
b/src/wok/plugins/gingerbase/ui/pages/host.html.tmpl
index ff7db9b..d17f184 100644
--- a/src/wok/plugins/gingerbase/ui/pages/host.html.tmpl
+++ b/src/wok/plugins/gingerbase/ui/pages/host.html.tmpl
@@ -57,7 +57,7 @@
<div id="host-content-container"
class="empty-when-logged-off"></div>
</div>
-<script id="host-tmpl" type="kimchi/template">
+<script id="host-tmpl" type="gingerbase/template">
<div class="host-dashboard">
<div class="container">
<div id="alert-container"></div>
@@ -150,7 +150,7 @@
<div id="modalWindow" class="modal fade host-modal"
tabindex="-1" role="dialog"
aria-labelledby="hostsModalLabel" aria-hidden="true">
</div>
<script type="text/javascript">
- kimchi.host_main();
+ gingerbase.host_main();
</script>
</body>
</html>
diff --git a/src/wok/plugins/gingerbase/ui/pages/report-add.html.tmpl
b/src/wok/plugins/gingerbase/ui/pages/report-add.html.tmpl
index 94f4ed6..8208009 100644
--- a/src/wok/plugins/gingerbase/ui/pages/report-add.html.tmpl
+++ b/src/wok/plugins/gingerbase/ui/pages/report-add.html.tmpl
@@ -44,5 +44,5 @@
</div>
</div>
<script>
- kimchi.report_add_main();
+ gingerbase.report_add_main();
</script>
\ No newline at end of file
diff --git a/src/wok/plugins/gingerbase/ui/pages/report-rename.html.tmpl
b/src/wok/plugins/gingerbase/ui/pages/report-rename.html.tmpl
index e5b9401..84b879e 100644
--- a/src/wok/plugins/gingerbase/ui/pages/report-rename.html.tmpl
+++ b/src/wok/plugins/gingerbase/ui/pages/report-rename.html.tmpl
@@ -45,6 +45,6 @@
</div>
</div>
<script>
- kimchi.report_rename_main();
+ gingerbase.report_rename_main();
</script>
\ No newline at end of file
diff --git a/src/wok/plugins/gingerbase/ui/pages/repository-add.html.tmpl
b/src/wok/plugins/gingerbase/ui/pages/repository-add.html.tmpl
index 3bf0856..7a48617 100644
--- a/src/wok/plugins/gingerbase/ui/pages/repository-add.html.tmpl
+++ b/src/wok/plugins/gingerbase/ui/pages/repository-add.html.tmpl
@@ -68,6 +68,6 @@
</div>
</div>
<script>
- kimchi.repository_add_main();
+ gingerbase.repository_add_main();
</script>
\ No newline at end of file
diff --git a/src/wok/plugins/gingerbase/ui/pages/repository-edit.html.tmpl
b/src/wok/plugins/gingerbase/ui/pages/repository-edit.html.tmpl
index 9e1c54f..c468e4b 100644
--- a/src/wok/plugins/gingerbase/ui/pages/repository-edit.html.tmpl
+++ b/src/wok/plugins/gingerbase/ui/pages/repository-edit.html.tmpl
@@ -74,6 +74,6 @@
</div>
</div>
<script type="text/javascript">
- kimchi.repository_edit_main();
+ gingerbase.repository_edit_main();
</script>
\ No newline at end of file
diff --git a/src/wok/plugins/gingerbase/model/host.py
b/src/wok/plugins/gingerbase/model/host.py
index 670fec5..f48c001 100644
--- a/src/wok/plugins/gingerbase/model/host.py
+++ b/src/wok/plugins/gingerbase/model/host.py
@@ -178,7 +178,7 @@ class SoftwareUpdateProgressModel(object):
except:
raise OperationFailed('GGBPKGUPD0004E')
- taskid = add_task('/plugins/kimchi/host/swupdateprogress',
+ taskid = add_task('/plugins/gingerbase/host/swupdateprogress',
swupdate.tailUpdateLogs, self.objstore, None)
return self.task.lookup(taskid)
@@ -229,7 +229,7 @@ class HostStatsModel(object):
# The psutil.cpu_percent works as non blocking.
# psutil.cpu_percent maintains a cpu time sample.
# It will update the cpu time sample when it is called.
# So only this producer can call psutil.cpu_percent in kimchi.
self.host_stats['cpu_utilization'].append(psutil.cpu_percent(None))
def _get_host_memory_stats(self):
@@ -229,7 +229,7 @@ class HostStatsModel(object):
# psutil.cpu_percent maintains a cpu time sample.
# It will update the cpu time sample when it is called.
- # So only this producer can call psutil.cpu_percent in kimchi.
+ # So only this producer can call psutil.cpu_percent in gingerbase.
self.host_stats['cpu_utilization'].append(psutil.cpu_percent(None))
def _get_host_memory_stats(self):
diff --git a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.host.js
b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.host.js
index 5e99346..24a4aa6 100644
--- a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.host.js
+++ b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.host.js
@@ -15,9 +15,9 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-kimchi.host = {};
+gingerbase.host = {};
-kimchi.host_main = function() {
+gingerbase.host_main = function() {
"use strict";
var repositoriesGrid = null;
var initRepositoriesGrid = function(repo_type) {
@@ -106,8 +106,8 @@ kimchi.host_main = function() {
var name = repository['repo_id'];
var enable = !repository['enabled'];
$(this).prop('disabled', true);
- kimchi.enableRepository(name, enable, function() {
- wok.topic('kimchi/repositoryUpdated').publish();
+ gingerbase.enableRepository(name, enable, function() {
+ wok.topic('gingerbase/repositoryUpdated').publish();
});
}
}, {
@@ -120,7 +120,7 @@ kimchi.host_main = function() {
if (!repository) {
return;
}
- kimchi.selectedRepository = repository['repo_id'];
+ gingerbase.selectedRepository = repository['repo_id'];
wok.window.open({
url: 'plugins/gingerbase/repository-edit.html',
class: repo_type
@@ -146,10 +146,10 @@ kimchi.host_main = function() {
};
wok.confirm(settings, function() {
- kimchi.deleteRepository(
+ gingerbase.deleteRepository(
repository['repo_id'],
function(result) {
-
wok.topic('kimchi/repositoryDeleted').publish(result);
+
wok.topic('gingerbase/repositoryDeleted').publish(result);
},
function(error) {}
);
@@ -175,7 +175,7 @@ kimchi.host_main = function() {
};
var listRepositories = function(gridCallback) {
- kimchi.listRepositories(function(repositories) {
+ gingerbase.listRepositories(function(repositories) {
if ($.isFunction(gridCallback)) {
gridCallback(repositories);
} else {
@@ -231,10 +231,10 @@ kimchi.host_main = function() {
progressArea.scrollIntoView();
$(updateButton).text(i18n['GGBUPD6007M']).prop('disabled', true);
- kimchi.updateSoftware(function(result) {
+ gingerbase.updateSoftware(function(result) {
reloadProgressArea(result);
$(updateButton).text(i18n['GGBUPD6006M']).prop('disabled', false);
- wok.topic('kimchi/softwareUpdated').publish({
+ wok.topic('gingerbase/softwareUpdated').publish({
result: result
});
}, function(error) {
@@ -273,9 +273,9 @@ kimchi.host_main = function() {
!wok.isElementInViewport(progressArea) &&
progressArea.scrollIntoView();
- kimchi.softwareUpdateProgress(function(result) {
+ gingerbase.softwareUpdateProgress(function(result) {
reloadProgressArea(result);
- wok.topic('kimchi/softwareUpdated').publish({
+ wok.topic('gingerbase/softwareUpdated').publish({
result: result
});
wok.message.warn(i18n['GGBUPD6010M']);
@@ -285,7 +285,7 @@ kimchi.host_main = function() {
};
var listSoftwareUpdates = function(gridCallback) {
- kimchi.listSoftwareUpdates(function(softwareUpdates) {
+ gingerbase.listSoftwareUpdates(function(softwareUpdates) {
if ($.isFunction(gridCallback)) {
gridCallback(softwareUpdates);
} else {
@@ -353,7 +353,7 @@ kimchi.host_main = function() {
return;
}
- kimchi.selectedReport = report['name'];
+ gingerbase.selectedReport = report['name'];
wok.window.open('plugins/gingerbase/report-rename.html');
}
}, {
@@ -367,7 +367,7 @@ kimchi.host_main = function() {
return;
}
- kimchi.downloadReport({
+ gingerbase.downloadReport({
file: report['uri']
});
}
@@ -391,7 +391,7 @@ kimchi.host_main = function() {
};
wok.confirm(settings, function() {
- kimchi.deleteReport({
+ gingerbase.deleteReport({
name: report['name']
}, function(result) {
listDebugReports();
@@ -434,31 +434,31 @@ kimchi.host_main = function() {
var reports = [];
var filter = 'status=running&target_uri=' +
encodeURIComponent('^/plugins/gingerbase/debugreports/*');
- kimchi.getTasksByFilter(filter, function(tasks) {
+ gingerbase.getTasksByFilter(filter, function(tasks) {
for (var i = 0; i < tasks.length; i++) {
- var reportName =
tasks[i].target_uri.replace(/^\/plugins\/kimchi\/debugreports\//, '') ||
i18n['GGBDR6012M'];
+ var reportName =
tasks[i].target_uri.replace(/^\/plugins\/gingerbase\/debugreports\//, '') ||
i18n['GGBDR6012M'];
reports.push({
'name': reportName,
'time': i18n['GGBDR6007M']
});
- if (kimchi.trackingTasks.indexOf(tasks[i].id) >= 0) {
+ if (gingerbase.trackingTasks.indexOf(tasks[i].id) >= 0) {
continue;
}
- kimchi.trackTask(tasks[i].id, function(result) {
- wok.topic('kimchi/debugReportAdded').publish();
+ gingerbase.trackTask(tasks[i].id, function(result) {
+ wok.topic('gingerbase/debugReportAdded').publish();
}, function(result) {
// Error message from Async Task status
if (result['message']) {
var errText = result['message'];
}
// Error message from standard kimchi exception
else {
var errText = result['responseJSON']['reason'];
}
result && wok.message.error(errText);
- wok.topic('kimchi/debugReportAdded').publish();
+ wok.topic('gingerbase/debugReportAdded').publish();
}, null);
}
}, null, true);
@@ -467,11 +467,11 @@ kimchi.host_main = function() {
};
var listDebugReports = function() {
- kimchi.listReports(function(reports) {
+ gingerbase.listReports(function(reports) {
var pendingReports = getPendingReports();
var allReports = pendingReports.concat(reports);
$('#debug-report-section').removeClass('hidden');
- if ((kimchi.capabilities['repo_mngt_tool']) &&
(kimchi.capabilities['repo_mngt_tool'] !== "None")) {
+ if ((gingerbase.capabilities['repo_mngt_tool']) &&
(gingerbase.capabilities['repo_mngt_tool'] !== "None")) {
$('#debug-report-section,
#repositories-section').removeClass('col-md-8');
$('#debug-report-section,
#repositories-section').addClass('col-md-4');
} else {
@@ -509,7 +509,7 @@ kimchi.host_main = function() {
if (error['status'] === 403) {
$('#debug-report-section').addClass('hidden');
// Check Repositories and resize column
- if ((kimchi.capabilities['repo_mngt_tool']) &&
(kimchi.capabilities['repo_mngt_tool'] !== "None")) {
+ if ((gingerbase.capabilities['repo_mngt_tool']) &&
(gingerbase.capabilities['repo_mngt_tool'] !== "None")) {
$('#repositories-section').removeClass('col-md-4');
$('#repositories-section').addClass('col-md-8');
} else {
@@ -519,7 +519,7 @@ kimchi.host_main = function() {
return;
}
$('#debug-report-section').removeClass('hidden');
- if ((kimchi.capabilities['repo_mngt_tool']) &&
(kimchi.capabilities['repo_mngt_tool'] !== "None")) {
+ if ((gingerbase.capabilities['repo_mngt_tool']) &&
(gingerbase.capabilities['repo_mngt_tool'] !== "None")) {
$('#debug-report-section,
#repositories-section').removeClass('col-md-8');
$('#debug-report-section,
#repositories-section').addClass('col-md-4');
} else {
@@ -539,11 +539,11 @@ kimchi.host_main = function() {
};
wok.confirm(settings, function() {
- kimchi.shutdown(params);
+ gingerbase.shutdown(params);
$(shutdownButtonID).prop('disabled', true);
$(restartButtonID).prop('disabled', true);
// Check if there is any VM is running.
- kimchi.listVMs(function(vms) {
+ gingerbase.listVMs(function(vms) {
for (var i = 0; i < vms.length; i++) {
if (vms[i]['state'] === 'running') {
wok.message.error.code('GGBHOST6001E');
@@ -572,43 +572,43 @@ kimchi.host_main = function() {
});
var setupUI = function() {
- if (kimchi.capabilities === undefined) {
+ if (gingerbase.capabilities === undefined) {
setTimeout(setupUI, 2000);
return;
}
- if ((kimchi.capabilities['repo_mngt_tool']) &&
(kimchi.capabilities['repo_mngt_tool'] !== "None")) {
- initRepositoriesGrid(kimchi.capabilities['repo_mngt_tool']);
- $('#repositories-section').switchClass('hidden',
kimchi.capabilities['repo_mngt_tool']);
- $('#content-sys-info').removeClass('col-md-12',
kimchi.capabilities['repo_mngt_tool']);
- $('#content-sys-info').addClass('col-md-4',
kimchi.capabilities['repo_mngt_tool']);
- wok.topic('kimchi/repositoryAdded')
+ if ((gingerbase.capabilities['repo_mngt_tool']) &&
(gingerbase.capabilities['repo_mngt_tool'] !== "None")) {
+ initRepositoriesGrid(gingerbase.capabilities['repo_mngt_tool']);
+ $('#repositories-section').switchClass('hidden',
gingerbase.capabilities['repo_mngt_tool']);
+ $('#content-sys-info').removeClass('col-md-12',
gingerbase.capabilities['repo_mngt_tool']);
+ $('#content-sys-info').addClass('col-md-4',
gingerbase.capabilities['repo_mngt_tool']);
+ wok.topic('gingerbase/repositoryAdded')
.subscribe(listRepositories);
- wok.topic('kimchi/repositoryUpdated')
+ wok.topic('gingerbase/repositoryUpdated')
.subscribe(listRepositories);
- wok.topic('kimchi/repositoryDeleted')
+ wok.topic('gingerbase/repositoryDeleted')
.subscribe(listRepositories);
}
- if (kimchi.capabilities['update_tool']) {
+ if (gingerbase.capabilities['update_tool']) {
$('#software-update-section').removeClass('hidden');
initSoftwareUpdatesGrid();
- wok.topic('kimchi/softwareUpdated')
+ wok.topic('gingerbase/softwareUpdated')
.subscribe(listSoftwareUpdates);
}
- if (kimchi.capabilities['system_report_tool']) {
+ if (gingerbase.capabilities['system_report_tool']) {
listDebugReports();
- wok.topic('kimchi/debugReportAdded')
+ wok.topic('gingerbase/debugReportAdded')
.subscribe(listDebugReports);
- wok.topic('kimchi/debugReportRenamed')
+ wok.topic('gingerbase/debugReportRenamed')
.subscribe(listDebugReports);
}
};
setupUI();
};
- kimchi.getHost(function(data) {
+ gingerbase.getHost(function(data) {
var htmlTmpl = $('#host-tmpl').html();
data['logo'] = data['logo'] || '';
data['memory'] = wok.formatMeasurement(data['memory'], {
@@ -830,14 +830,14 @@ kimchi.host_main = function() {
};
var track = function() {
- kimchi.getHostStatsHistory(statsCallback,
+ gingerbase.getHostStatsHistory(statsCallback,
function() {
continueTrack();
});
};
var continueTrack = function() {
- kimchi.getHostStats(statsCallback,
+ gingerbase.getHostStats(statsCallback,
function() {
continueTrack();
});
@@ -857,9 +857,9 @@ kimchi.host_main = function() {
var initTracker = function() {
// TODO: Extend tabs with onUnload event to unregister timers.
- if (kimchi.hostTimer) {
- kimchi.hostTimer.stop();
- delete kimchi.hostTimer;
+ if (gingerbase.hostTimer) {
+ gingerbase.hostTimer.stop();
+ delete gingerbase.hostTimer;
}
var trackedCharts = {
@@ -885,33 +885,33 @@ kimchi.host_main = function() {
})
};
- if (kimchi.hostTimer) {
- kimchi.hostTimer.setCharts(trackedCharts);
+ if (gingerbase.hostTimer) {
+ gingerbase.hostTimer.setCharts(trackedCharts);
} else {
- kimchi.hostTimer = new Tracker(trackedCharts);
- kimchi.hostTimer.start();
+ gingerbase.hostTimer = new Tracker(trackedCharts);
+ gingerbase.hostTimer.start();
}
};
$('#host-root-container').on('remove', function() {
- if (kimchi.hostTimer) {
- kimchi.hostTimer.stop();
- delete kimchi.hostTimer;
+ if (gingerbase.hostTimer) {
+ gingerbase.hostTimer.stop();
+ delete gingerbase.hostTimer;
}
repositoriesGrid && repositoriesGrid.destroy();
- wok.topic('kimchi/repositoryAdded')
+ wok.topic('gingerbase/repositoryAdded')
.unsubscribe(listRepositories);
- wok.topic('kimchi/repositoryUpdated')
+ wok.topic('gingerbase/repositoryUpdated')
.unsubscribe(listRepositories);
- wok.topic('kimchi/repositoryDeleted')
+ wok.topic('gingerbase/repositoryDeleted')
.unsubscribe(listRepositories);
softwareUpdatesGrid && softwareUpdatesGrid.destroy();
- wok.topic('kimchi/softwareUpdated').unsubscribe(listSoftwareUpdates);
+
wok.topic('gingerbase/softwareUpdated').unsubscribe(listSoftwareUpdates);
reportGrid && reportGrid.destroy();
- wok.topic('kimchi/debugReportAdded').unsubscribe(listDebugReports);
- wok.topic('kimchi/debugReportRenamed').unsubscribe(listDebugReports);
+ wok.topic('gingerbase/debugReportAdded').unsubscribe(listDebugReports);
+
wok.topic('gingerbase/debugReportRenamed').unsubscribe(listDebugReports);
});
-};
\ No newline at end of file
+};
@@ -434,31 +434,31 @@ kimchi.host_main = function() {
var errText = result['message'];
}
- // Error message from standard kimchi exception
+ // Error message from standard gingerbase exception
else {
var errText = result['responseJSON']['reason'];
diff --git a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.report_add_main.js
b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.report_add_main.js
index 105465d..29cc84d 100644
--- a/src/wok/plugins/gingerbase/ui/js/src/gingerbase.report_add_main.js
+++ b/src/wok/plugins/gingerbase/ui/js/src/gingerbase.report_add_main.js
@@ -17,7 +17,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-kimchi.report_add_main = function() {
+gingerbase.report_add_main = function() {
var reportGridID = 'available-reports-grid';
var addReportForm = $('#form-report-add');
var submitButton = $('#button-report-add');
@@ -42,18 +42,18 @@ kimchi.report_add_main = function() {
}
taskAccepted = true;
wok.window.close();
- wok.topic('kimchi/debugReportAdded').publish();
+ wok.topic('gingerbase/debugReportAdded').publish();
};
- kimchi.createReport(formData, function(result) {
+ gingerbase.createReport(formData, function(result) {
onTaskAccepted();
- wok.topic('kimchi/debugReportAdded').publish();
+ wok.topic('gingerbase/debugReportAdded').publish();
}, function(result) {
// Error message from Async Task status
if (result['message']) {
var errText = result['message'];
}
// Error message from standard kimchi exception
else {
var errText = result['responseJSON']['reason'];
}
@@ -42,18 +42,18 @@ kimchi.report_add_main = function() {
var errText = result['message'];
}
- // Error message from standard kimchi exception
+ // Error message from standard gingerbase exception
else {
var errText = result['responseJSON']['reason'];
--
2.5.0